==> rendition-11.13.0.tgz: package/dist_esm5/components/Pager/index.js <==
import { __assign, __rest } from "tslib";
import * as React from 'react';
import FaChevronLeft from 'react-icons/lib/fa/chevron-left';
import FaChevronRight from 'react-icons/lib/fa/chevron-right';
import Button from '../Button';
import ButtonGroup from '../ButtonGroup';
import { Flex } from '../Grid';
import Txt from '../Txt';
var Pager = function (_a) {
    var totalItems = _a.totalItems, itemsPerPage = _a.itemsPerPage, page = _a.page, nextPage = _a.nextPage, prevPage = _a.prevPage, props = __rest(_a, ["totalItems", "itemsPerPage", "page", "nextPage", "prevPage"]);
    var lowerBound = page * itemsPerPage;
    var upperBound = Math.min((page + 1) * itemsPerPage, totalItems);
    return (React.createElement(Flex, __assign({ justifyContent: "flex-end", alignItems: "center" }, props),
        React.createElement(Txt, { mr: 2 },
            React.createElement("strong", null,
                lowerBound + 1,
                " - ",
                upperBound),
            ' ',
            "of ",
            React.createElement("strong", null, totalItems)),
        React.createElement(Flex, null,
            React.createElement(ButtonGroup, null,
                React.createElement(Button, { quartenary: true, outline: true, className: "rendition-pager__btn--prev", disabled: totalItems <= itemsPerPage || page <= 0, onClick: function () { return prevPage(); }, icon: React.createElement(FaChevronLeft, null) }),
                React.createElement(Button, { quartenary: true, outline: true, className: "rendition-pager__btn--next", disabled: totalItems <= itemsPerPage ||
                        totalItems / itemsPerPage <= page + 1, onClick: function () { return nextPage(); }, icon: React.createElement(FaChevronRight, null) })))));
};
export default Pager;

==> rendition-11.16.4.tgz: package/dist_esm5/components/Pager/index.js <==
import { __assign, __rest } from "tslib";
import * as React from 'react';
import FaChevronLeft from 'react-icons/lib/fa/chevron-left';
import FaChevronRight from 'react-icons/lib/fa/chevron-right';
import Button from '../Button';
import ButtonGroup from '../ButtonGroup';
import { Flex } from '../Flex';
import Txt from '../Txt';
var Pager = function (_a) {
    var totalItems = _a.totalItems, itemsPerPage = _a.itemsPerPage, page = _a.page, nextPage = _a.nextPage, prevPage = _a.prevPage, props = __rest(_a, ["totalItems", "itemsPerPage", "page", "nextPage", "prevPage"]);
    var lowerBound = page * itemsPerPage;
    var upperBound = Math.min((page + 1) * itemsPerPage, totalItems);
    return (React.createElement(Flex, __assign({ justifyContent: "flex-end", alignItems: "center" }, props),
        React.createElement(Txt, { mr: 2 },
            React.createElement("strong", null,
                lowerBound + 1,
                " - ",
                upperBound),
            ' ',
            "of ",
            React.createElement("strong", null, totalItems)),
        React.createElement(Flex, null,
            React.createElement(ButtonGroup, null,
                React.createElement(Button, { quartenary: true, outline: true, className: "rendition-pager__btn--prev", disabled: totalItems <= itemsPerPage || page <= 0, onClick: function () { return prevPage(); }, icon: React.createElement(FaChevronLeft, null) }),
                React.createElement(Button, { quartenary: true, outline: true, className: "rendition-pager__btn--next", disabled: totalItems <= itemsPerPage ||
                        totalItems / itemsPerPage <= page + 1, onClick: function () { return nextPage(); }, icon: React.createElement(FaChevronRight, null) })))));
};
export default Pager;
